@@ -6,19 +6,24 @@ import re
 import subprocess
 import sys
 import threading
-from collections.abc import Sequence
 from contextlib import suppress
 from functools import lru_cache
 from pathlib import Path
 from shutil import which
-from typing import Any, ClassVar, Generic, TextIO, TypeVar
+from typing import TYPE_CHECKING, Any, ClassVar, Generic, TextIO, TypeVar
 
 from streamlink import StreamError
 from streamlink.stream.stream import Stream, StreamIO
-from streamlink.utils.named_pipe import NamedPipe, NamedPipeBase
+from streamlink.utils.named_pipe import NamedPipe
 from streamlink.utils.processoutput import ProcessOutput
 
 
+if TYPE_CHECKING:
+    from collections.abc import Sequence
+
+    from streamlink.utils.named_pipe import NamedPipeBase
+
+
 log = logging.getLogger(__name__)
 
 _lock_resolve_command = threading.Lock()
@@ -104,14 +109,21 @@ class FFMPEGMuxer(StreamIO):
     @classmethod
     def command(cls, session):
         with _lock_resolve_command:
+            timeout = session.options.get("ffmpeg-validation-timeout") or cls.FFMPEG_VERSION_TIMEOUT
             return cls._resolve_command(
                 session.options.get("ffmpeg-ffmpeg"),
                 not session.options.get("ffmpeg-no-validation"),
+                timeout,
             )
 
     @classmethod
     @lru_cache(maxsize=128)
-    def _resolve_command(cls, command: str | None = None, validate: bool = True) -> str | None:
+    def _resolve_command(
+        cls,
+        command: str | None = None,
+        validate: bool = True,
+        timeout: float = FFMPEG_VERSION_TIMEOUT,
+    ) -> str | None:
         if command:
             resolved = which(command)
         else:
@@ -123,7 +135,7 @@ class FFMPEGMuxer(StreamIO):
 
         if resolved and validate:
             log.trace(f"Querying FFmpeg version: {[resolved, '-version']}")  # type: ignore[attr-defined]
-            versionoutput = FFmpegVersionOutput([resolved, "-version"], timeout=cls.FFMPEG_VERSION_TIMEOUT)
+            versionoutput = FFmpegVersionOutput([resolved, "-version"], timeout=timeout)
             if not versionoutput.run():
                 log.error("Could not validate FFmpeg!")
                 log.error(f"Unexpected FFmpeg version output while running {[resolved, '-version']}")
@@ -184,7 +196,7 @@ class FFMPEGMuxer(StreamIO):
                 target=self.copy_to_pipe,
                 args=(self, stream, np),
             )
-            for stream, np in zip(self.streams, self.pipes)
+            for stream, np in zip(self.streams, self.pipes, strict=True)
         ]
 
         loglevel = session.options.get("ffmpeg-loglevel") or options.pop("loglevel", self.DEFAULT_LOGLEVEL)
@@ -241,7 +253,7 @@ class FFMPEGMuxer(StreamIO):
         return self
 
     def read(self, size=-1):
-        return self.process.stdout.read(size)
+        return self.process.stdout.read(size)  # type: ignore[attr-defined]
 
     def close(self):
         if self.closed:
@@ -251,7 +263,7 @@ class FFMPEGMuxer(StreamIO):
         if self.process:
             # kill ffmpeg
             self.process.kill()
-            self.process.stdout.close()
+            self.process.stdout.close()  # type: ignore[attr-defined]
 
             executor = concurrent.futures.ThreadPoolExecutor()
 
@@ -272,7 +284,7 @@ class FFMPEGMuxer(StreamIO):
             ]  # fmt: skip
             concurrent.futures.wait(futures, return_when=concurrent.futures.ALL_COMPLETED)
 
-        if self.errorlog is not sys.stderr and self.errorlog is not subprocess.DEVNULL:
+        if self.errorlog is not sys.stderr and not isinstance(self.errorlog, int):
             with suppress(OSError):
                 self.errorlog.close()
 
